import React, { useState, useEffect } from 'react';
import axios from 'axios';
import { Prism as SyntaxHighlighter } from 'react-syntax-highlighter';
import { lightTheme } from '../styles/lightTheme'; // Import your custom light theme
import { darkTheme } from '../styles/darkTheme'; // Import your custom dark theme

const GistViewer = ({ gistId }) => {
  const [gistContent, setGistContent] = useState(null);
  const [error, setError] = useState(null);
  const [theme, setTheme] = useState(darkTheme); // Default to dark theme
  const [bgColor, setBgColor] = useState('#007bff'); // Initial button background color

  useEffect(() => {
    const fetchGist = async () => {
      try {
        const response = await axios.get(`https://api.github.com/gists/${gistId}`);
        const gistFiles = response.data.files;
        const file = Object.keys(gistFiles)[0]; // Assume we want the first file.
        setGistContent(gistFiles[file].content);
      } catch (err) {
        setError('Error fetching Gist');
      }
    };

    fetchGist();
  }, [gistId]);

  // Toggle between dark and light themes
  const toggleTheme = () => {
    setTheme(theme === darkTheme ? lightTheme : darkTheme);
  };

  // Hover handlers for background color change
  const handleMouseEnter = () => {
    setBgColor('#026b5a'); // Change to a new color on hover
  };

  const handleMouseLeave = () => {
    setBgColor('#38b09d'); // Revert to original color when not hovering
  };

  if (error) {
    return <div>{error}</div>;
  }

  const divStyle = {
    display: 'flex',       // Use flexbox layout
    justifyContent: 'space-between', // Space the buttons apart
    gap: '1rem',           // Add gap between buttons
    alignItems: 'center',  // Align items vertically in the center
  };
  return (
    <div>
      <div style={divStyle}>
        <button
          onClick={toggleTheme}
          onMouseEnter={handleMouseEnter}
          onMouseLeave={handleMouseLeave}
          style={{
            paddingTop: '0.5rem',
            paddingBottom: '0.5rem',
            paddingRight: '1rem',
            paddingLeft: '1rem',
            borderRadius: '1rem',
            cursor: 'pointer',
            backgroundColor: bgColor, // Dynamic background color
            color: 'white', // Button text color
            border: 'none',
          }}
        >
          changeMode
        </button>

        <a target='_blank' href="https://buymeacoffee.com/sagarsuri">
          <button
            onMouseEnter={handleMouseEnter}
            onMouseLeave={handleMouseLeave}
            style={{
              paddingTop: '0.5rem',
              paddingBottom: '0.5rem',
              paddingRight: '1rem',
              paddingLeft: '1rem',
              borderRadius: '1rem',
              cursor: 'pointer',
              backgroundColor: bgColor, // Dynamic background color
              color: 'white', // Button text color
              border: 'none',
            }}
          >
            Donate
          </button>
        </a>
      </div>

      {gistContent ? (
        <SyntaxHighlighter language="javascript" style={theme}>
          {gistContent}
        </SyntaxHighlighter>
      ) : (
        <div>Loading Gist...</div>
      )}
    </div>
  );
};

export default GistViewer;
